import pandas as pd
from utils.DataIO import file_rw


def test_file_rw_csv():
    # Test the write functionality
    df = pd.DataFrame({'a': [1, 2, 3], 'b': [4, 5, 6]})
    file_rw('test_csv', df, mode='write', file_extension='csv')
    # Test the read functionality
    df2 = file_rw('test_csv', mode='read', file_extension='csv',  column_name=['a', 'b'])
    print(df2)
    assert df.equals(df2)
    # assert True


def test_file_rw_pickle():
    # Test the write functionality
    obj = {'a': 1, 'b': 2}
    file_rw('test_pickle', obj, mode='write', file_extension='pkl')
    # Test the read functionality
    obj2 = file_rw('test_pickle', mode='read', file_extension='pkl')
    assert obj == obj2





import os

from pathlib import Path
from dependence.function_write import *
from dependence.function_read import *
from dependence.control_folder_exist import *

__all__ = [
    "file_rw",
           ]


def file_rw(file_path, data=None, mode='read', sep=',', file_extension='csv', parent_directory=None, serie=False,
            column_name=None, use_cols=None):
    """
    A function to read or write data to a file. Supports CSV, JSON, and Pickle file formats.

    Parameters:
    ----------
    file_path : str
        The path to the file.
    data : pandas.DataFrame or pandas.Series or any Python object, optional
        The data to be written to the file, by default None.
    file_extension : str, optional
        The file format, either 'csv', 'json', or 'pkl', by default 'csv'.
    mode : str, optional
        The mode in which the file is opened, either 'read' or 'write', by default 'read'.
    parent_directory : str, optional
        allows to save in a specific folder, by default None
    serie: bool = False,
        Read a csv to return a Pandas series
    use_col: Type[str] = None
        If the parameter "serie" is true, allows to select the column to read. If None, all columns will be read.
    column_name: list or None, optional
        A list of new column names for the DataFrame, by default None.
    Returns:
    -------
    pandas.DataFrame or pandas.Series or any Python object
        The data read from the file.
    """
    directory = "dataset"
    if parent_directory is None:
        folder_path = Path(f"{directory}/data_{file_extension}")
        file_root = f"{directory}/data_{file_extension}/{file_path}.{file_extension}"
    else:
        folder_path = Path(parent_directory)
        os.makedirs(parent_directory, exist_ok=True)
        file_root = f"{parent_directory}/{file_path}.{file_extension}"

    if not folder_path.exists():
        print("the path to the file does not exist, create the destination.")
        folder_path.mkdir(parents=True, exist_ok=True)

    file_path = Path(file_root)

    if mode == 'read':
        if file_extension == 'csv':
            if serie:
                usecols = [use_cols] if use_cols else None
                return read_csv(file_path, sep=sep, column_names=column_name, use_cols=usecols, squeeze=True)
            return read_csv(file_path, sep=sep, column_names=column_name)
        elif file_extension == 'json':
            return read_json(file_path)
        elif file_extension == 'pkl':
            return read_pickle(file_path)
        else:
            print("error extension file")
    elif mode == 'write':
        if file_extension == 'csv':
            return write_csv(file_path, data=data, sep=sep, column_names=column_name)
        elif file_extension == 'json':
            return write_csv(file_path, data=data)
        elif file_extension == 'pkl':
            return write_pickle(file_path, data=data)
        else:
            print("error extension file")
    else:
        raise ValueError("'mode' must be either 'read' or 'write'")



import pickle
import pandas as pd


def write_pickle(file_path, data):
    with open(file_path, 'wb') as file:
        pickle.dump(data, file)


def write_csv(file_path, data, sep=',', column_names=None):
    data.to_csv(file_path, index=False, sep=sep, header=column_names is not None, columns=column_names)


def write_json(file_path, data):
    with open(file_path, 'w') as file:
        pd.json.dump(data.to_dict(), file)


def test_write():
    print("je sais ecrire")


import pickle

import pandas as pd


def read_csv(file_path, sep=',', column_names=None, use_cols=None, squeeze=False):
    return pd.read_csv(file_path, sep=sep, header=None, names=column_names, usecols=use_cols, squeeze=squeeze)


def read_json(file_path):
    with open(file_path, 'r') as file:
        return pd.read_json(file, lines=True)


def read_pickle(file_path):
    with open(file_path, 'rb') as file:
        return pickle.load(file)


def test_read():
    print("je sais lire")


from setuptools import setup, find_packages

setup(
    name='rw_dataframe_data_io',
    version='0.1.2',
    description='A function to read or write data to a file. Supports CSV, JSON, and Pickle file formats.',
    url='https://github.com/dicesare/data_io.git',
    author='antony coco',
    author_email='antony.coco.pro@gmail.com',
    packages=find_packages(),
    install_requires=[
        'pandas>=1.3.0',
        'numpy>=1.23.0',
        'pathlib>=1.0.0'
    ],
    entry_points={
        'console_scripts': [
            'rw-dataframe-data-io=rw_dataframe_data_io.module:fonction'
        ]
    },
    test_suite='tests',
    tests_require=['pytest'],
    python_requires='>=3.8',
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
)